.. :changelog:

History
-------

0.1.2
-----

* Documentation
* Fix excessive debugging info on default interface and help

0.1.1
-----

* Updated pychapter version to support automatic torrent searching
* Added support for 
    - IMDB interface
    - Magnet links (via pipe) interface
    - ShowRSS.info interface

0.1.0 (2015-01-11)
---------------------

* First release on PyPI.
